/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#include "TextObject.h"

namespace GB2 {

void TextObject::setText(const QString& newText) {
	text = newText;
	setModified(true);
}

GObject* TextObject::clone() const {
	TextObject* cln = new TextObject(text, getGObjectName(), getGHintsMap());
    cln->setIndexInfo(getIndexInfo());
    return cln;
}


}//namespace


